# Summarization

The `Summarization` task generates concise summaries of the documents.

## Usage

```python
--8<-- "sieves/tests/docs/test_task_usage.py:summarization-usage"
```

---

::: sieves.tasks.predictive.summarization.core
::: sieves.tasks.predictive.summarization.bridges
